@@ -22,7 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-__all__: tuple = ("DisGuildTemplate", "DisGuild")
+__all__: tuple = ("DisGuildTemplate", "Guild")
 
 from typing import Text, NewType, Union, Optional
 
@@ -162,7 +162,7 @@ class DisGuildTemplate:
         self.name = data["name"]
         self.description: Union[str, None] = data["description"]
         self.usage_count: int = int(data["usage_count"])
-        self.creator: disspy.user.DisUser = disspy.user.DisUser(
+        self.creator = disspy.user.User(
             data["creator"], self._t
         )
 
@@ -232,7 +232,7 @@ class DisGuildTemplate:
         return int(j["id"])
 
 
-class DisGuild:
+class Guild:
     """
     Info
     --------
