@@ -22,10 +22,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-__all__: tuple = ("DisUser",)
+__all__: tuple = "User",
 
 
-class DisUser:
+class User:
     """
     User object
     """
